@@ -142,8 +142,11 @@ func (p *Proxy) handleQUICStream(stream quic.Stream, session quic.Session) {
 			// Check for EDNS TCP keepalive option
 			if option.Option() == dns.EDNS0TCPKEEPALIVE {
 				log.Debug("client sent EDNS0 TCP keepalive option")
-				// Already closing the connection so we don't care about the error
-				_ = session.CloseWithError(0, "")
+				errorCode := quic.ApplicationErrorCode(quic.ConnectionRefused)
+
+				// Already closing the connection so we don't care about the error.
+				_ = session.CloseWithError(errorCode, "")
+				return
 			}
 		}
 	}
@@ -163,6 +166,12 @@ func (p *Proxy) handleQUICStream(stream quic.Stream, session quic.Session) {
 func (p *Proxy) respondQUIC(d *DNSContext) error {
 	resp := d.Res
 
+	if resp == nil {
+		// If no response has been written, close the QUIC session right away.
+		errorCode := quic.ApplicationErrorCode(quic.InternalError)
+		return d.QUICSession.CloseWithError(errorCode, "")
+	}
+
 	bytes, err := resp.Pack()
 	if err != nil {
 		return errorx.Decorate(err, "couldn't convert message into wire format: %s", resp.String())
@@ -189,8 +198,7 @@ func isQuicConnClosedErr(err error) bool {
 		return true
 	}
 
-	// NO_ERROR: No recent network activity
-	if strings.Contains(str, "NO_ERROR") {
+	if strings.Contains(str, "No recent network activity") {
 		return true
 	}
 
